@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 import re
 import sys
@@ -16,12 +16,17 @@ def dexuescape(s):
     r'''decode the \x, \u and \U in a escaped string -> encoded string'''
     s = escape_x_re.sub(lambda m: m.group().decode('string-escape'), s)
     s = escape_u_re.sub(lambda m: m.group().decode('unicode-escape').encode(encoding), s)
+
+    # for Python < 2.7
+    if isinstance(s, unicode):
+        s = s.encode(encoding)
+
     return s
 
 # make uniout
 uniout = lambda: 'middleware of stdout' # any instance
 
-# make uniout to look like stdout
+# make uniout look like stdout
 for attrname in dir(sys.stdout):
     if not attrname.startswith('__'):
         setattr(uniout, attrname, getattr(sys.stdout, attrname))
